summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorCorey Swenson <cswenson@us.ibm.com>2019-01-23 10:39:36 -0600
committerDaniel M. Crowell <dcrowell@us.ibm.com>2019-02-04 11:07:10 -0600
commitddae90ce735c06ef02931daf89fe38b16c8e0381 (patch)
treebebb68a6de13328805d26b70f55fbd8e98f212f8 /src
parent52080a90a556b0ad24b08dc50e81f18a7bfaf819 (diff)
downloadblackbird-hostboot-ddae90ce735c06ef02931daf89fe38b16c8e0381.tar.gz
blackbird-hostboot-ddae90ce735c06ef02931daf89fe38b16c8e0381.zip
Make MCS acker workaround changes permanent
Workaround moved the p9_revert_sbe_mcs_setup HWP from istep06 to istep14. Remove call_host_revert_sbe_mcs_setup.C from istep06 and remove workaround comments in istep14. Change-Id: I93c70364b7dde013bf003cf1920535ba78b9a58b RTC:184860 Reviewed-on: http://rchgit01.rchland.ibm.com/gerrit1/70792 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins OP Build CI <op-jenkins+hostboot@us.ibm.com> Reviewed-by: Christian R. Geddes <crgeddes@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins OP HW <op-hw-jenkins+hostboot@us.ibm.com> Reviewed-by: Matt Derksen <mderkse1@us.ibm.com> Reviewed-by: Daniel M. Crowell <dcrowell@us.ibm.com>
Diffstat (limited to 'src')
-rw-r--r--src/include/usr/isteps/istep06list.H18
-rw-r--r--src/usr/isteps/istep06/call_host_revert_sbe_mcs_setup.C94
-rw-r--r--src/usr/isteps/istep06/makefile3
-rw-r--r--src/usr/isteps/istep14/call_proc_setup_bars.C18
-rw-r--r--src/usr/isteps/istep14/makefile3
5 files changed, 18 insertions, 118 deletions
diff --git a/src/usr/isteps/istep06/call_host_revert_sbe_mcs_setup.C b/src/usr/isteps/istep06/call_host_revert_sbe_mcs_setup.C
deleted file mode 100644
index d328e0e85..000000000
--- a/src/usr/isteps/istep06/call_host_revert_sbe_mcs_setup.C
+++ /dev/null
@@ -1,94 +0,0 @@
-/* IBM_PROLOG_BEGIN_TAG */
-/* This is an automatically generated prolog. */
-/* */
-/* $Source: src/usr/isteps/istep06/call_host_revert_sbe_mcs_setup.C $ */
-/* */
-/* OpenPOWER HostBoot Project */
-/* */
-/* Contributors Listed Below - COPYRIGHT 2015,2018 */
-/* [+] International Business Machines Corp. */
-/* */
-/* */
-/* Licensed under the Apache License, Version 2.0 (the "License"); */
-/* you may not use this file except in compliance with the License. */
-/* You may obtain a copy of the License at */
-/* */
-/* http://www.apache.org/licenses/LICENSE-2.0 */
-/* */
-/* Unless required by applicable law or agreed to in writing, software */
-/* distributed under the License is distributed on an "AS IS" BASIS, */
-/* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or */
-/* implied. See the License for the specific language governing */
-/* permissions and limitations under the License. */
-/* */
-/* IBM_PROLOG_END_TAG */
-
-#include <stdint.h>
-
-#include <trace/interface.H>
-#include <errl/errlentry.H>
-#include <errl/errlmanager.H>
-
-#include <isteps/hwpisteperror.H>
-#include <initservice/isteps_trace.H>
-#include <initservice/initserviceif.H>
-#include <targeting/common/commontargeting.H>
-#include <targeting/common/util.H>
-#include <targeting/common/utilFilter.H>
-#include <targeting/common/target.H>
-
-#include <fapi2.H>
-#include <fapi2/plat_hwp_invoker.H>
-#include <p9_revert_sbe_mcs_setup.H>
-
-namespace ISTEP_06
-{
-
-void* call_host_revert_sbe_mcs_setup( void *io_pArgs )
-{
- errlHndl_t l_err = NULL;
- ISTEP_ERROR::IStepError l_stepError;
-
- TRACDCOMP( ISTEPS_TRACE::g_trac_isteps_trace,
- "call_host_revert_sbe_mcs_setup entry" );
-
- TARGETING::Target * l_masterProc;
- TARGETING::targetService().masterProcChipTargetHandle( l_masterProc );
-
- TRACFCOMP(ISTEPS_TRACE::g_trac_isteps_trace,
- "Running p9_revert_sbe_mcs_setup on "
- "target HUID %.8X",
- TARGETING::get_huid(l_masterProc));
-
- // cast the target to a fapi2 target
- fapi2::Target<fapi2::TARGET_TYPE_PROC_CHIP> l_fapi_master_proc( l_masterProc );
-
- //Invoke p9_revert_sbe_mcs_setup
- // Pass in boolean describing if we are using the FSP or not
- // If we are using the FSP then we will ask off the SBE fir
- // bits on the TP Local Fir register as the FSP with handle
- // SBE errors
- // TODO: RTC 184860 Remove MCS acker workaround
- //FAPI_INVOKE_HWP( l_err, p9_revert_sbe_mcs_setup,
- // l_fapi_master_proc,
- // INITSERVICE::spBaseServicesEnabled());
-
- if (l_err)
- {
- TRACFCOMP(ISTEPS_TRACE::g_trac_isteps_trace,
- "ERROR 0x%.8X: p9_revert_sbe_mcs_setup",
- l_err->reasonCode());
- // Create IStep error log and cross reference error
- l_stepError.addErrorDetails(l_err);
- // Commit error
- errlCommit(l_err,SBE_COMP_ID);
- }
-
-
- TRACDCOMP( ISTEPS_TRACE::g_trac_isteps_trace,
- "call_host_revert_sbe_mcs_setup exit" );
-
- return l_stepError.getErrorHandle();
-}
-
-};
diff --git a/src/usr/isteps/istep06/makefile b/src/usr/isteps/istep06/makefile
index e5e273e18..3ad69565f 100644
--- a/src/usr/isteps/istep06/makefile
+++ b/src/usr/isteps/istep06/makefile
@@ -5,7 +5,7 @@
#
# OpenPOWER HostBoot Project
#
-# Contributors Listed Below - COPYRIGHT 2015,2018
+# Contributors Listed Below - COPYRIGHT 2015,2019
# [+] International Business Machines Corp.
#
#
@@ -30,7 +30,6 @@ OBJS += host_set_ipl_parms.o
OBJS += host_discover_targets.o
OBJS += call_host_update_master_tpm.o
OBJS += host_gard.o
-OBJS += call_host_revert_sbe_mcs_setup.o
OBJS += host_start_occ_xstop_handler.o
OBJS += call_host_voltage_config.o
diff --git a/src/usr/isteps/istep14/call_proc_setup_bars.C b/src/usr/isteps/istep14/call_proc_setup_bars.C
index 08d1708d3..25ed067d2 100644
--- a/src/usr/isteps/istep14/call_proc_setup_bars.C
+++ b/src/usr/isteps/istep14/call_proc_setup_bars.C
@@ -5,7 +5,7 @@
/* */
/* OpenPOWER HostBoot Project */
/* */
-/* Contributors Listed Below - COPYRIGHT 2015,2018 */
+/* Contributors Listed Below - COPYRIGHT 2015,2019 */
/* [+] International Business Machines Corp. */
/* */
/* */
@@ -40,7 +40,6 @@
#include <p9_mss_setup_bars.H>
#include <p9c_mss_secure_boot.H>
-// TODO: RTC 184860 Remove MCS acker workaround
#include <initservice/initserviceif.H>
#include <p9_revert_sbe_mcs_setup.H>
@@ -68,10 +67,11 @@ void* call_proc_setup_bars (void *io_pArgs)
"call_proc_setup_bars entry" );
- // *******************************
- // Start MCS acker workaround
- // TODO: RTC 184860 Remove MCS acker workaround
- // *******************************
+ // ***************************
+ // Start MCS reset
+ // Reset memory controller configuration written by SBE
+ // Close the MCS acker before enabling the real memory bars
+ // ***************************
TARGETING::Target * l_masterProc;
TARGETING::targetService().masterProcChipTargetHandle( l_masterProc );
@@ -102,9 +102,9 @@ void* call_proc_setup_bars (void *io_pArgs)
// Commit error
errlCommit(l_errl,SBE_COMP_ID);
}
- // *******************************
- // End MCS acker workaround
- // *******************************
+ // ***************************
+ // End MCS reset
+ // ***************************
// Get all processor targets
diff --git a/src/usr/isteps/istep14/makefile b/src/usr/isteps/istep14/makefile
index 68156f5b1..253ee9c38 100644
--- a/src/usr/isteps/istep14/makefile
+++ b/src/usr/isteps/istep14/makefile
@@ -5,7 +5,7 @@
#
# OpenPOWER HostBoot Project
#
-# Contributors Listed Below - COPYRIGHT 2015,2018
+# Contributors Listed Below - COPYRIGHT 2015,2019
# [+] International Business Machines Corp.
#
#
@@ -78,7 +78,6 @@ OBJS += p9c_mss_thermal_init.o
OBJS += p9c_mss_unmask_errors.o
OBJS += p9c_mss_power_cleanup.o
OBJS += p9c_cen_stopclocks.o
-# TODO: RTC 184860 Remove MCS acker workaround
OBJS += p9_revert_sbe_mcs_setup.o
#include ${PROCEDURE_PATH}/hwp/nest/p9_htm_setup.mk
OpenPOWER on IntegriCloud
diff --git a/src/include/usr/isteps/istep06list.H b/src/include/usr/isteps/istep06list.H
index 873509eda..170837c02 100644
--- a/src/include/usr/isteps/istep06list.H
+++ b/src/include/usr/isteps/istep06list.H
@@ -5,7 +5,7 @@
/* */
/* OpenPOWER HostBoot Project */
/* */
-/* Contributors Listed Below - COPYRIGHT 2012,2018 */
+/* Contributors Listed Below - COPYRIGHT 2012,2019 */
/* [+] International Business Machines Corp. */
/* */
/* */
@@ -52,7 +52,7 @@
* 06.9 host_gard
* : Do Gard
* 06.10 host_revert_sbe_mcs_setup
* : Clean up MCS extent regs
* 06.11 host_start_occ_xstop_handler
* : Start OpenPOWER xstop
* 06.12 host_voltage_config
@@ -128,13 +128,9 @@ void* call_host_update_master_tpm( void *io_pArgs );
void* host_gard( void *io_pArgs );
/**
- * @brief host_revert_sbe_mcs_setup (istep 6.10)
- *
- * param[in,out] io_pArgs - (normally) a pointer to a TaskArgs struct,
- * or NULL.
- * return any error logs to istep
+ * host_revert_sbe_mcs_setup (istep 6.10)
+ * Moved to istep14 call_proc_setup_bars.C
*/
-void* call_host_revert_sbe_mcs_setup (void * io_pArgs);
/**
* @brief host_start_occ_xstop_handler (istep 6.11)
@@ -213,9 +209,9 @@ const TaskInfo g_istep06[] = {
{ START_FN, EXT_IMAGE, NORMAL_IPL_OP | MPIPL_OP, false }
},
{
- ISTEPNAME(06,10,"host_revert_sbe_mcs_setup"),
- ISTEP_06::call_host_revert_sbe_mcs_setup,
- { START_FN, EXT_IMAGE, NORMAL_IPL_OP, false }
+ ISTEPNAME(06,10,""), // not used. moved to istep14
+ NULL,
+ { NONE, EXT_IMAGE, IPL_NOOP, false }
},
{
ISTEPNAME(06,11,"host_start_occ_xstop_handler"),
@@ -52,7 +52,7 @@
* : Do Gard
* 06.10 host_revert_sbe_mcs_setup
- * : Clean up MCS extent regs
+ * : Clean up MCS extent regs (moved to istep14)
* 06.11 host_start_occ_xstop_handler
* : Start OpenPOWER xstop